Module blaxel.core.client.models.create_job_execution_request_tasks_item
========================================================================

Classes
-------

`CreateJobExecutionRequestTasksItem()`
:   Method generated by attrs for class CreateJobExecutionRequestTasksItem.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :